# Bootstrappable Cloud9 Instance with SSM

Simple stack example:

```ts
export class Cloud9EnvironmentExampleStack extends cdk.Stack {
  constructor(scope: Construct, id: string, props?: cdk.StackProps) {
    super(scope, id, props);

    // Create L2 Cloud9 Environment
    const environment = new Cloud9Environment(this, "environment", {
      name: "example-environment",
      description: "An example environment",
      imageId: Cloud9AmiType.AMZN_LINUX_2,
      connectionType: Cloud9ConnectionType.SSM,
      ownerArn: "<YOUR_ARN>",
    });

    // Existing CodeCommit Repository
    const repository = Repository.fromRepositoryName(this, "test", "test-repo");
    // Clone Git Repositories within Cloud9 Environment
    environment.cloneCodeCommitRepo(repository, "test");
    environment.cloneGitRepo(
      "https://github.com/aws-samples/aws-copilot-pubsub",
      "copilot"
    );

    environment.addInitCommands(["sudo yum update -y", "sudo yum install -y jq"]);

    //-----------------------------------------------------
    //-                  Outputs                         -
    //-----------------------------------------------------
    new cdk.CfnOutput(this, "environmentUrl", {
      value: environment.environmentUrl,
      description: "The URL of the environment",
    });
  }
}
```

# API Reference <a name="API Reference" id="api-reference"></a>

## Constructs <a name="Constructs" id="Constructs"></a>

### Cloud9Environment <a name="Cloud9Environment" id="bootstrappable-cloud9.Cloud9Environment"></a>

A Cloud 9 Environment with bootstrapping capabilities leveraging SSM automation.

#### Initializers <a name="Initializers" id="bootstrappable-cloud9.Cloud9Environment.Initializer"></a>

```typescript
import { Cloud9Environment } from 'bootstrappable-cloud9'

new Cloud9Environment(scope: Construct, id: string, props: Cloud9EnvironmentProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#bootstrappable-cloud9.Cloud9Environment.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#bootstrappable-cloud9.Cloud9Environment.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#bootstrappable-cloud9.Cloud9Environment.Initializer.parameter.props">props</a></code> | <code><a href="#bootstrappable-cloud9.Cloud9EnvironmentProps">Cloud9EnvironmentProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="bootstrappable-cloud9.Cloud9Environment.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="bootstrappable-cloud9.Cloud9Environment.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Required</sup> <a name="props" id="bootstrappable-cloud9.Cloud9Environment.Initializer.parameter.props"></a>

- *Type:* <a href="#bootstrappable-cloud9.Cloud9EnvironmentProps">Cloud9EnvironmentProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#bootstrappable-cloud9.Cloud9Environment.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#bootstrappable-cloud9.Cloud9Environment.addInitCommands">addInitCommands</a></code> | Adds bash commands to the Cloud9 environment initialization script. |
| <code><a href="#bootstrappable-cloud9.Cloud9Environment.cloneCodeCommitRepo">cloneCodeCommitRepo</a></code> | Clones a Code Commit repository into the Cloud9 environment. |
| <code><a href="#bootstrappable-cloud9.Cloud9Environment.cloneGitRepo">cloneGitRepo</a></code> | Clones a public GitHub repository into the Cloud9 environment. |

---

##### `toString` <a name="toString" id="bootstrappable-cloud9.Cloud9Environment.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addInitCommands` <a name="addInitCommands" id="bootstrappable-cloud9.Cloud9Environment.addInitCommands"></a>

```typescript
public addInitCommands(commands: string[]): void
```

Adds bash commands to the Cloud9 environment initialization script.

Commands such as `yum install <package>` should include the sudo prefix.

###### `commands`<sup>Required</sup> <a name="commands" id="bootstrappable-cloud9.Cloud9Environment.addInitCommands.parameter.commands"></a>

- *Type:* string[]

bash commands to execute in the Cloud9 environment.

---

##### `cloneCodeCommitRepo` <a name="cloneCodeCommitRepo" id="bootstrappable-cloud9.Cloud9Environment.cloneCodeCommitRepo"></a>

```typescript
public cloneCodeCommitRepo(repository: IRepository, environmentPath: string): void
```

Clones a Code Commit repository into the Cloud9 environment.

###### `repository`<sup>Required</sup> <a name="repository" id="bootstrappable-cloud9.Cloud9Environment.cloneCodeCommitRepo.parameter.repository"></a>

- *Type:* aws-cdk-lib.aws_codecommit.IRepository

the CodeCommit repository.

---

###### `environmentPath`<sup>Required</sup> <a name="environmentPath" id="bootstrappable-cloud9.Cloud9Environment.cloneCodeCommitRepo.parameter.environmentPath"></a>

- *Type:* string

the path within Cloud9 where it will be cloned.

---

##### `cloneGitRepo` <a name="cloneGitRepo" id="bootstrappable-cloud9.Cloud9Environment.cloneGitRepo"></a>

```typescript
public cloneGitRepo(repositoryUrl: string, environmentPath: string): void
```

Clones a public GitHub repository into the Cloud9 environment.

###### `repositoryUrl`<sup>Required</sup> <a name="repositoryUrl" id="bootstrappable-cloud9.Cloud9Environment.cloneGitRepo.parameter.repositoryUrl"></a>

- *Type:* string

the HTTPS URL of the repository.

---

###### `environmentPath`<sup>Required</sup> <a name="environmentPath" id="bootstrappable-cloud9.Cloud9Environment.cloneGitRepo.parameter.environmentPath"></a>

- *Type:* string

the path within Cloud9 where it will be cloned.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#bootstrappable-cloud9.Cloud9Environment.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="bootstrappable-cloud9.Cloud9Environment.isConstruct"></a>

```typescript
import { Cloud9Environment } from 'bootstrappable-cloud9'

Cloud9Environment.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="bootstrappable-cloud9.Cloud9Environment.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#bootstrappable-cloud9.Cloud9Environment.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#bootstrappable-cloud9.Cloud9Environment.property.environmentId">environmentId</a></code> | <code>string</code> | *No description.* |
| <code><a href="#bootstrappable-cloud9.Cloud9Environment.property.environmentUrl">environmentUrl</a></code> | <code>string</code> | *No description.* |
| <code><a href="#bootstrappable-cloud9.Cloud9Environment.property.instanceId">instanceId</a></code> | <code>string</code> | *No description.* |
| <code><a href="#bootstrappable-cloud9.Cloud9Environment.property.instanceRole">instanceRole</a></code> | <code>aws-cdk-lib.aws_iam.IRole</code> | *No description.* |
| <code><a href="#bootstrappable-cloud9.Cloud9Environment.property.privateIp">privateIp</a></code> | <code>string</code> | *No description.* |
| <code><a href="#bootstrappable-cloud9.Cloud9Environment.property.repositories">repositories</a></code> | <code>aws-cdk-lib.aws_cloud9.CfnEnvironmentEC2.RepositoryProperty[]</code> | *No description.* |
| <code><a href="#bootstrappable-cloud9.Cloud9Environment.property.resource">resource</a></code> | <code>aws-cdk-lib.aws_cloud9.CfnEnvironmentEC2</code> | *No description.* |
| <code><a href="#bootstrappable-cloud9.Cloud9Environment.property.securityGroup">securityGroup</a></code> | <code>aws-cdk-lib.aws_ec2.ISecurityGroup</code> | *No description.* |
| <code><a href="#bootstrappable-cloud9.Cloud9Environment.property.steps">steps</a></code> | <code>object[]</code> | *No description.* |

---

##### `node`<sup>Required</sup> <a name="node" id="bootstrappable-cloud9.Cloud9Environment.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `environmentId`<sup>Required</sup> <a name="environmentId" id="bootstrappable-cloud9.Cloud9Environment.property.environmentId"></a>

```typescript
public readonly environmentId: string;
```

- *Type:* string

---

##### `environmentUrl`<sup>Required</sup> <a name="environmentUrl" id="bootstrappable-cloud9.Cloud9Environment.property.environmentUrl"></a>

```typescript
public readonly environmentUrl: string;
```

- *Type:* string

---

##### `instanceId`<sup>Required</sup> <a name="instanceId" id="bootstrappable-cloud9.Cloud9Environment.property.instanceId"></a>

```typescript
public readonly instanceId: string;
```

- *Type:* string

---

##### `instanceRole`<sup>Required</sup> <a name="instanceRole" id="bootstrappable-cloud9.Cloud9Environment.property.instanceRole"></a>

```typescript
public readonly instanceRole: IRole;
```

- *Type:* aws-cdk-lib.aws_iam.IRole

---

##### `privateIp`<sup>Required</sup> <a name="privateIp" id="bootstrappable-cloud9.Cloud9Environment.property.privateIp"></a>

```typescript
public readonly privateIp: string;
```

- *Type:* string

---

##### `repositories`<sup>Required</sup> <a name="repositories" id="bootstrappable-cloud9.Cloud9Environment.property.repositories"></a>

```typescript
public readonly repositories: RepositoryProperty[];
```

- *Type:* aws-cdk-lib.aws_cloud9.CfnEnvironmentEC2.RepositoryProperty[]

---

##### `resource`<sup>Required</sup> <a name="resource" id="bootstrappable-cloud9.Cloud9Environment.property.resource"></a>

```typescript
public readonly resource: CfnEnvironmentEC2;
```

- *Type:* aws-cdk-lib.aws_cloud9.CfnEnvironmentEC2

---

##### `securityGroup`<sup>Required</sup> <a name="securityGroup" id="bootstrappable-cloud9.Cloud9Environment.property.securityGroup"></a>

```typescript
public readonly securityGroup: ISecurityGroup;
```

- *Type:* aws-cdk-lib.aws_ec2.ISecurityGroup

---

##### `steps`<sup>Required</sup> <a name="steps" id="bootstrappable-cloud9.Cloud9Environment.property.steps"></a>

```typescript
public readonly steps: object[];
```

- *Type:* object[]

---


## Structs <a name="Structs" id="Structs"></a>

### Cloud9EnvironmentProps <a name="Cloud9EnvironmentProps" id="bootstrappable-cloud9.Cloud9EnvironmentProps"></a>

#### Initializer <a name="Initializer" id="bootstrappable-cloud9.Cloud9EnvironmentProps.Initializer"></a>

```typescript
import { Cloud9EnvironmentProps } from 'bootstrappable-cloud9'

const cloud9EnvironmentProps: Cloud9EnvironmentProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#bootstrappable-cloud9.Cloud9EnvironmentProps.property.connectionType">connectionType</a></code> | <code><a href="#bootstrappable-cloud9.Cloud9ConnectionType">Cloud9ConnectionType</a></code> | The type of connection method to use. |
| <code><a href="#bootstrappable-cloud9.Cloud9EnvironmentProps.property.automaticStopTime">automaticStopTime</a></code> | <code>aws-cdk-lib.Duration</code> | The amount of time to wait for the environment to stop. |
| <code><a href="#bootstrappable-cloud9.Cloud9EnvironmentProps.property.description">description</a></code> | <code>string</code> | The description of the environment. |
| <code><a href="#bootstrappable-cloud9.Cloud9EnvironmentProps.property.imageId">imageId</a></code> | <code><a href="#bootstrappable-cloud9.Cloud9AmiType">Cloud9AmiType</a></code> | The identifier for the Amazon Machine Image (AMI) that's used to create the EC2 instance. |
| <code><a href="#bootstrappable-cloud9.Cloud9EnvironmentProps.property.instanceType">instanceType</a></code> | <code>aws-cdk-lib.aws_ec2.InstanceType</code> | The type of EC2 instance to use. |
| <code><a href="#bootstrappable-cloud9.Cloud9EnvironmentProps.property.name">name</a></code> | <code>string</code> | The name of the environment. |
| <code><a href="#bootstrappable-cloud9.Cloud9EnvironmentProps.property.ownerArn">ownerArn</a></code> | <code>string</code> | The Amazon Resource Name (ARN) of the environment owner. |
| <code><a href="#bootstrappable-cloud9.Cloud9EnvironmentProps.property.subnet">subnet</a></code> | <code>aws-cdk-lib.aws_ec2.ISubnet</code> | The subnet to use for the environment. |
| <code><a href="#bootstrappable-cloud9.Cloud9EnvironmentProps.property.tags">tags</a></code> | <code>aws-cdk-lib.CfnTag[]</code> | The tags to apply to the environment. |

---

##### `connectionType`<sup>Required</sup> <a name="connectionType" id="bootstrappable-cloud9.Cloud9EnvironmentProps.property.connectionType"></a>

```typescript
public readonly connectionType: Cloud9ConnectionType;
```

- *Type:* <a href="#bootstrappable-cloud9.Cloud9ConnectionType">Cloud9ConnectionType</a>
- *Default:* SSM

The type of connection method to use.

---

##### `automaticStopTime`<sup>Optional</sup> <a name="automaticStopTime" id="bootstrappable-cloud9.Cloud9EnvironmentProps.property.automaticStopTime"></a>

```typescript
public readonly automaticStopTime: Duration;
```

- *Type:* aws-cdk-lib.Duration
- *Default:* 30 minutes

The amount of time to wait for the environment to stop.

---

##### `description`<sup>Optional</sup> <a name="description" id="bootstrappable-cloud9.Cloud9EnvironmentProps.property.description"></a>

```typescript
public readonly description: string;
```

- *Type:* string
- *Default:* None

The description of the environment.

---

##### `imageId`<sup>Optional</sup> <a name="imageId" id="bootstrappable-cloud9.Cloud9EnvironmentProps.property.imageId"></a>

```typescript
public readonly imageId: Cloud9AmiType;
```

- *Type:* <a href="#bootstrappable-cloud9.Cloud9AmiType">Cloud9AmiType</a>
- *Default:* AMZN_LINUX_2

The identifier for the Amazon Machine Image (AMI) that's used to create the EC2 instance.

---

##### `instanceType`<sup>Optional</sup> <a name="instanceType" id="bootstrappable-cloud9.Cloud9EnvironmentProps.property.instanceType"></a>

```typescript
public readonly instanceType: InstanceType;
```

- *Type:* aws-cdk-lib.aws_ec2.InstanceType
- *Default:* t3.small

The type of EC2 instance to use.

---

##### `name`<sup>Optional</sup> <a name="name" id="bootstrappable-cloud9.Cloud9EnvironmentProps.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string
- *Default:* A Cloud9-generated

The name of the environment.

---

##### `ownerArn`<sup>Optional</sup> <a name="ownerArn" id="bootstrappable-cloud9.Cloud9EnvironmentProps.property.ownerArn"></a>

```typescript
public readonly ownerArn: string;
```

- *Type:* string
- *Default:* This environment creator (careful, this might be the CloudFormation role!).

The Amazon Resource Name (ARN) of the environment owner.

---

##### `subnet`<sup>Optional</sup> <a name="subnet" id="bootstrappable-cloud9.Cloud9EnvironmentProps.property.subnet"></a>

```typescript
public readonly subnet: ISubnet;
```

- *Type:* aws-cdk-lib.aws_ec2.ISubnet

The subnet to use for the environment.

---

##### `tags`<sup>Optional</sup> <a name="tags" id="bootstrappable-cloud9.Cloud9EnvironmentProps.property.tags"></a>

```typescript
public readonly tags: CfnTag[];
```

- *Type:* aws-cdk-lib.CfnTag[]

The tags to apply to the environment.

---

### RepositoryCloneProps <a name="RepositoryCloneProps" id="bootstrappable-cloud9.RepositoryCloneProps"></a>

#### Initializer <a name="Initializer" id="bootstrappable-cloud9.RepositoryCloneProps.Initializer"></a>

```typescript
import { RepositoryCloneProps } from 'bootstrappable-cloud9'

const repositoryCloneProps: RepositoryCloneProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#bootstrappable-cloud9.RepositoryCloneProps.property.environmentPath">environmentPath</a></code> | <code>string</code> | *No description.* |
| <code><a href="#bootstrappable-cloud9.RepositoryCloneProps.property.repositoryUrl">repositoryUrl</a></code> | <code>string</code> | *No description.* |

---

##### `environmentPath`<sup>Required</sup> <a name="environmentPath" id="bootstrappable-cloud9.RepositoryCloneProps.property.environmentPath"></a>

```typescript
public readonly environmentPath: string;
```

- *Type:* string

---

##### `repositoryUrl`<sup>Required</sup> <a name="repositoryUrl" id="bootstrappable-cloud9.RepositoryCloneProps.property.repositoryUrl"></a>

```typescript
public readonly repositoryUrl: string;
```

- *Type:* string

---



## Enums <a name="Enums" id="Enums"></a>

### Cloud9AmiType <a name="Cloud9AmiType" id="bootstrappable-cloud9.Cloud9AmiType"></a>

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#bootstrappable-cloud9.Cloud9AmiType.AMZN_LINUX_1">AMZN_LINUX_1</a></code> | *No description.* |
| <code><a href="#bootstrappable-cloud9.Cloud9AmiType.AMZN_LINUX_2">AMZN_LINUX_2</a></code> | *No description.* |
| <code><a href="#bootstrappable-cloud9.Cloud9AmiType.UBUNTU_18_04">UBUNTU_18_04</a></code> | *No description.* |
| <code><a href="#bootstrappable-cloud9.Cloud9AmiType.UBUNTU_22_04">UBUNTU_22_04</a></code> | *No description.* |

---

##### `AMZN_LINUX_1` <a name="AMZN_LINUX_1" id="bootstrappable-cloud9.Cloud9AmiType.AMZN_LINUX_1"></a>

---


##### `AMZN_LINUX_2` <a name="AMZN_LINUX_2" id="bootstrappable-cloud9.Cloud9AmiType.AMZN_LINUX_2"></a>

---


##### `UBUNTU_18_04` <a name="UBUNTU_18_04" id="bootstrappable-cloud9.Cloud9AmiType.UBUNTU_18_04"></a>

---


##### `UBUNTU_22_04` <a name="UBUNTU_22_04" id="bootstrappable-cloud9.Cloud9AmiType.UBUNTU_22_04"></a>

---


### Cloud9ConnectionType <a name="Cloud9ConnectionType" id="bootstrappable-cloud9.Cloud9ConnectionType"></a>

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#bootstrappable-cloud9.Cloud9ConnectionType.SSH">SSH</a></code> | This method accesses the environment using SSH and requires open inbound ports. |
| <code><a href="#bootstrappable-cloud9.Cloud9ConnectionType.SSM">SSM</a></code> | This method accesses the environment using SSM (Sytems Manager) without opening inbound ports. |

---

##### `SSH` <a name="SSH" id="bootstrappable-cloud9.Cloud9ConnectionType.SSH"></a>

This method accesses the environment using SSH and requires open inbound ports.

---


##### `SSM` <a name="SSM" id="bootstrappable-cloud9.Cloud9ConnectionType.SSM"></a>

This method accesses the environment using SSM (Sytems Manager) without opening inbound ports.

---

