import { CfnTag, Duration } from 'aws-cdk-lib';
import * as cloud9 from 'aws-cdk-lib/aws-cloud9';
import { IRepository } from 'aws-cdk-lib/aws-codecommit';
import * as ec2 from 'aws-cdk-lib/aws-ec2';
import { IRole } from 'aws-cdk-lib/aws-iam';
import { Construct } from 'constructs';
export declare enum Cloud9ConnectionType {
    /** This method accesses the environment using SSH and requires open inbound ports */
    SSH = "CONNECT_SSH",
    /** This method accesses the environment using SSM (Sytems Manager) without opening inbound ports. */
    SSM = "CONNECT_SSM"
}
export declare enum Cloud9AmiType {
    AMZN_LINUX_1 = "resolve:ssm:/aws/service/cloud9/amis/amazonlinux-1-x86_64",
    AMZN_LINUX_2 = "resolve:ssm:/aws/service/cloud9/amis/amazonlinux-2-x86_64",
    UBUNTU_18_04 = "resolve:ssm:/aws/service/cloud9/amis/ubuntu-18.04-x86_64",
    UBUNTU_22_04 = "resolve:ssm:/aws/service/cloud9/amis/ubuntu-22.04-x86_64"
}
export interface RepositoryCloneProps {
    readonly repositoryUrl: string;
    readonly environmentPath: string;
}
export interface Cloud9EnvironmentProps {
    /**
     * The amount of time to wait for the environment to stop.
     * @default - 30 minutes
     */
    readonly automaticStopTime?: Duration;
    /**
     * The type of EC2 instance to use.
     * @default - t3.small
     */
    readonly instanceType?: ec2.InstanceType;
    /**
     * The type of connection method to use.
     * @default - SSM
     */
    readonly connectionType: Cloud9ConnectionType;
    /**
     * The name of the environment.
     * @default - A Cloud9-generated
     */
    readonly name?: string;
    /**
     * The description of the environment.
     * @default - None
     */
    readonly description?: string;
    /**
     * The identifier for the Amazon Machine Image (AMI) that's used to create the EC2 instance.
     * @default - AMZN_LINUX_2
     */
    readonly imageId?: Cloud9AmiType;
    /**
     * The Amazon Resource Name (ARN) of the environment owner.
     * @default - This environment creator (careful, this might be the CloudFormation role!).
     */
    readonly ownerArn?: string;
    /**
     * The subnet to use for the environment.
     */
    readonly subnet?: ec2.ISubnet;
    /**
     * The tags to apply to the environment.
     */
    readonly tags?: Array<CfnTag>;
}
/**
 * A Cloud 9 Environment with bootstrapping capabilities leveraging SSM automation.
 */
export declare class Cloud9Environment extends Construct {
    readonly repositories: cloud9.CfnEnvironmentEC2.RepositoryProperty[];
    readonly resource: cloud9.CfnEnvironmentEC2;
    readonly environmentUrl: string;
    readonly environmentId: string;
    readonly instanceId: string;
    readonly securityGroup: ec2.ISecurityGroup;
    readonly privateIp: string;
    readonly instanceRole: IRole;
    steps: object[];
    constructor(scope: Construct, id: string, props: Cloud9EnvironmentProps);
    /**
     * Clones a Code Commit repository into the Cloud9 environment.
     * @param repository the CodeCommit repository
     * @param environmentPath the path within Cloud9 where it will be cloned
     */
    cloneCodeCommitRepo(repository: IRepository, environmentPath: string): void;
    /**
     * Clones a public GitHub repository into the Cloud9 environment.
     * @param repositoryUrl  the HTTPS URL of the repository
     * @param environmentPath  the path within Cloud9 where it will be cloned
     */
    cloneGitRepo(repositoryUrl: string, environmentPath: string): void;
    /**
     * Adds bash commands to the Cloud9 environment initialization script.
     * Commands such as `yum install <package>` should include the sudo prefix.
     * @param commands bash commands to execute in the Cloud9 environment
     */
    addInitCommands(commands: string[]): void;
}
